@@ -1,7 +1,9 @@
 from django.contrib.auth import get_user_model
 
-from ..api.exceptions import RestApiException
-from ..conf import conf
+from ..api.exceptions import \
+    SMSWaitException, \
+    UserAlreadyExistException
+
 from ..models import PhoneCode
 from ..utils import SmsService
 
@@ -18,13 +20,13 @@ class GeneratorService(SmsService):
 
         if code is not None:
             if not code.is_allow:
-                raise RestApiException(detail={"detail": conf.SMS_WAIT_TIME})
+                raise SMSWaitException()
 
             code.delete()
 
         if self.owner is not None:
             if get_user_model().objects.filter(username=self.owner).exists():
-                raise RestApiException(detail={"detail": conf.SMS_USER_ALREADY_EXIST})
+                raise UserAlreadyExistException()
 
         PhoneCode.objects\
             .create(phone_number=self.phone_number,
